trame-xterm
===========================================================

Trame widget to expose xterm.js. This library is compatible with both vue2 and vue3.


License
-----------------------------------------------------------

This library is distributed under the MIT License (Same as xterm.js)


Development
-----------------------------------------------------------

Build and install the Vue components

.. code-block:: console

    cd vue-components
    npm i
    npm run build
    cd -

Install the python library

.. code-block:: console

    pip install -e .
